﻿#region License Information
/* HeuristicLab
 * Copyright (C) Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Linq;

namespace HeuristicLab.Problems.Instances.DataAnalysis {
  public class HydraulicConditionMonitoring : ResourceRegressionDataDescriptor {
    public HydraulicConditionMonitoring()
      : base("HydraulicConditionMonitoring.csv") { }

    public override string Name { get { return "Hydraulic Condition Monitoring"; } }
    public override string Description { get { return "The data set addresses the condition assessment of a hydraulic test rig based on multi sensor data. Four fault types are superimposed with several severity grades impeding selective quantification."; } }
    protected override string TargetVariable { get { return "Cooler condition"; } }  // or  "Valve condition", "Internal pump leakage", "Hydraulic accumulator"
    protected override string[] VariableNames {
      get { return AllowedInputVariables.Concat(new[] { "Cooler condition", "Valve condition", "Internal pump leakage", "Hydraulic accumulator", "stable flag" }).ToArray(); }
    }
    protected override string[] AllowedInputVariables {
      get {
        return new[] {
          "PS1", "PS2", "PS3", "PS4", "PS5", "PS6",
          "EPS1",
          "FS1", "FS2",
          "TS1", "TS2", "TS3", "TS4",
          "VS1",
          "CE",
          "CP",
          "SE"
        };
      }
    }
    protected override int TrainingPartitionStart { get { return 0; } }
    protected override int TrainingPartitionEnd { get { return 1470; } }
    protected override int TestPartitionStart { get { return 1470; } }
    protected override int TestPartitionEnd { get { return 2205; } }
  }
}