﻿#region License Information
/* HeuristicLab
 * Copyright (C) Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Linq;

namespace HeuristicLab.Problems.Instances.DataAnalysis {
  public class SocialMediaBuzzTomsHardware : ResourceRegressionDataDescriptor {
    public SocialMediaBuzzTomsHardware()
      : base("SocialMediaBuzz(TomsHardware).csv") { }

    public override string Name { get { return "Social Media Buzz (TomsHardware)"; } }
    public override string Description { get { return "This data-set contains examples of buzz events from Tom's Hardware, a forum network focusing on new technology with more conservative dynamics."; } }
    protected override string TargetVariable { get { return "Mean Number of display (ND)"; } }
    protected override string[] VariableNames {
      get { return AllowedInputVariables.Concat(new[] { "Mean Number of display (ND)" }).ToArray(); }
    }
    protected override string[] AllowedInputVariables {
      get {
        return new[] {
          "Number of Created Discussions (NCD)",
          "Burstiness Level (BL)",
          "Average Discussions Length (NAD)",
          "Author Increase (AI)",
          "Number of Atomic Containers (NAC)",
          "Number of displays (ND)",
          "Contribution Sparseness (CS)",
          "Author Interaction (AT)",
          "Number of Authors (NA)",
          "Average Discussions Length (ADL)",
          "Attention Level (measured with number of authors) (AS(NA))",
          "Attention Level (measured with number of contributions) (AS(NAC))"
        };
      }
    }
    protected override int TrainingPartitionStart { get { return 0; } }
    protected override int TrainingPartitionEnd { get { return 18786; } }
    protected override int TestPartitionStart { get { return 18786; } }
    protected override int TestPartitionEnd { get { return 28179; } }
  }
}